pub struct Hud {Show 35 fields
ui: Ui,
ids: Ids,
world_map: (Vec<Rotations>, Vec2<u32>),
imgs: Imgs,
item_imgs: ItemImgs,
item_i18n: ItemI18n,
fonts: Fonts,
rot_imgs: ImgsRot,
failed_block_pickups: HashMap<VolumePos, CollectFailedData>,
failed_entity_pickups: HashMap<Entity, CollectFailedData>,
new_loot_messages: VecDeque<LootMessage>,
new_messages: VecDeque<ChatMsg>,
new_notifications: VecDeque<UserNotification>,
speech_bubbles: HashMap<Uid, SpeechBubble>,
content_bubbles: Vec<(Vec3<f32>, SpeechBubble)>,
pub persisted_state: Rc<RefCell<PersistedHudState>>,
pub show: Show,
to_focus: Option<Option<Id>>,
force_ungrab: bool,
force_chat_input: Option<String>,
force_chat_cursor: Option<Index>,
tab_complete: Option<String>,
pulse: f32,
hp_pulse: f32,
slot_manager: SlotManager<SlotKind>,
hotbar: State,
events: Vec<Event>,
crosshair_opacity: f32,
floaters: Floaters,
voxel_minimap: VoxelMinimap,
map_drag: Vec2<f64>,
force_chat: bool,
clear_chat: bool,
current_dialogue: Option<(Entity, Instant, Dialogue<true>)>,
extra_markers: Vec<ExtraMarker>,
}Fields
ui: Uiids: Idsworld_map: (Vec<Rotations>, Vec2<u32>)imgs: Imgsitem_imgs: ItemImgsitem_i18n: ItemI18nfonts: Fontsrot_imgs: ImgsRotfailed_block_pickups: HashMap<VolumePos, CollectFailedData>failed_entity_pickups: HashMap<Entity, CollectFailedData>new_loot_messages: VecDeque<LootMessage>new_messages: VecDeque<ChatMsg>new_notifications: VecDeque<UserNotification>speech_bubbles: HashMap<Uid, SpeechBubble>content_bubbles: Vec<(Vec3<f32>, SpeechBubble)>persisted_state: Rc<RefCell<PersistedHudState>>show: Showto_focus: Option<Option<Id>>force_ungrab: boolforce_chat_input: Option<String>force_chat_cursor: Option<Index>tab_complete: Option<String>pulse: f32hp_pulse: f32slot_manager: SlotManager<SlotKind>hotbar: Stateevents: Vec<Event>crosshair_opacity: f32floaters: Floatersvoxel_minimap: VoxelMinimapmap_drag: Vec2<f64>force_chat: boolclear_chat: boolcurrent_dialogue: Option<(Entity, Instant, Dialogue<true>)>extra_markers: Vec<ExtraMarker>Implementations
Sourceimpl Hud
impl Hud
pub fn new( global_state: &mut GlobalState, persisted_state: Rc<RefCell<PersistedHudState>>, client: &Client, ) -> Self
pub fn clear_chat(&mut self)
pub fn set_prompt_dialog(&mut self, prompt_dialog: PromptDialogSettings)
pub fn update_fonts(&mut self, i18n: &Localization)
pub fn set_slots_use_prefixes(&mut self, use_prefixes: bool)
pub fn set_slots_prefix_switch_point(&mut self, prefix_switch_point: u32)
pub fn current_dialogue(&self) -> Option<EcsEntity>
fn update_layout( &mut self, client: &Client, global_state: &mut GlobalState, debug_info: &Option<DebugInfo>, dt: Duration, info: HudInfo<'_>, camera: &Camera, (entity_interactables, block_interactables): (HashMap<Entity, Vec<EntityInteraction>>, HashMap<VolumePos, (Block, Vec<&BlockInteraction>)>), ) -> Vec<Event>
fn show_bag( slot_manager: &mut SlotManager<SlotKind>, show: &mut Show, state: bool, )
pub fn add_failed_block_pickup( &mut self, pos: VolumePos, reason: HudCollectFailedReason, )
pub fn add_failed_entity_pickup( &mut self, entity: EcsEntity, reason: HudCollectFailedReason, )
pub fn new_loot_message(&mut self, item: LootMessage)
pub fn dialogue( &mut self, sender: EcsEntity, player_pos: Vec3<f32>, dialogue: Dialogue<true>, global_state: &mut GlobalState, )
pub fn new_message(&mut self, msg: ChatMsg)
pub fn new_notification(&mut self, msg: UserNotification)
pub fn set_scaling_mode(&mut self, scale_mode: ScaleMode)
pub fn scale_change(&mut self, scale_change: ScaleChange) -> ScaleMode
Sourcefn is_captured<W: Widget>(ui: &Ui) -> bool
fn is_captured<W: Widget>(ui: &Ui) -> bool
Checks if a widget of type W has captured the keyboard
pub fn handle_event( &mut self, event: WinEvent, global_state: &mut GlobalState, client_inventory: Option<&Inventory>, ) -> bool
pub fn maintain( &mut self, client: &Client, global_state: &mut GlobalState, debug_info: &Option<DebugInfo>, camera: &Camera, dt: Duration, info: HudInfo<'_>, interactable_map: (HashMap<Entity, Vec<EntityInteraction>>, HashMap<VolumePos, (Block, Vec<&BlockInteraction>)>), ) -> Vec<Event>
pub fn clear_cursor(&mut self)
pub fn render<'a>(&'a self, drawer: &mut UiDrawer<'_, 'a>)
pub fn free_look(&mut self, free_look: bool)
pub fn auto_walk(&mut self, auto_walk: bool)
pub fn camera_clamp(&mut self, camera_clamp: bool)
Sourcepub fn zoom_lock_reminder(&mut self)
pub fn zoom_lock_reminder(&mut self)
Remind the player camera zoom is currently locked, for example if they are trying to zoom.
Sourcepub fn zoom_lock_toggle(&mut self, state: bool)
pub fn zoom_lock_toggle(&mut self, state: bool)
Start showing a temporary notification (ChangeNotification) that zoom lock was toggled on/off.
pub fn show_content_bubble(&mut self, pos: Vec3<f32>, content: Content)
pub fn handle_outcome( &mut self, outcome: &Outcome, scene_data: &SceneData<'_>, global_state: &GlobalState, )